@@ -112,12 +112,20 @@ class ParquetData(SpreadSheetDataMixin, BaseData):
         if options is None:
             options = dict()
 
+        # get current position of stream
+        if data_utils.is_stream_buffer(file_path):
+            starting_location = file_path.tell()
+
         try:
             pfile = pq.ParquetFile(file_path)
             is_valid_parquet = True
         except:
             is_valid_parquet = False
 
+        # return to original position in stream
+        if data_utils.is_stream_buffer(file_path):
+            file_path.seek(starting_location, 0)
+
         return is_valid_parquet
 
     def reload(self, input_file_path=None, data=None, options=None):
